@@ -5,11 +5,9 @@ Modules for multi-asset analysis of finalcial time series.
     - CovMatrix
 """
 from .return_analysis import ReturnAnalysis
-from .covariance_analysis import CovMatrix
 
-del return_analysis, covariance_analysis  # noqa: F821
+del return_analysis  # noqa: F821
 
 __all__ = [
     "ReturnAnalysis",
-    "CovMatrix",
 ]
