@@ -1,5 +1,10 @@
 """
-This Module implement different portfolio optimization algorithms.
+This Module implement some portfolio optimization algorithms. Including:
+    - Risk Parity
+    - Hierarchical Risk Parity
+    - Inverse Variance
+    - Efficient Frontier
+    - Equal Weight
 """
 
 from .hrp import HierarchicalRiskParity
